#
# spec file for package cloud-init
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           cloud-init
Version:        0.7.6
Release:        28.3
License:        GPL-3.0
Summary:        Cloud node initialization tool
Url:            http://launchpad.net/cloud-init/
Group:          System/Management
Source0:        %{name}-%{version}.tar.gz
Source1:        cloud.cfg.suse
Source2:        rsyslog-cloud-init.cfg
Patch0:         suseSysVInit.diff
# FIXME addopenSUSEBase.patch proposed for upstream merge
Patch1:         addopenSUSEBase.patch
# FIXME suseIntegratedHandler.patch proposed for upstream merge
Patch2:         suseIntegratedHandler.patch
Patch3:         setupSUSEsysVInit.diff
# FIXME openSUSEhostsTemplate.diff proposed for upstream merge
Patch5:         openSUSEhostsTemplate.diff
# FIXME dynamicInitCmd.patch proposed for upstream merge
Patch6:         dynamicInitCmd.diff
Patch9:         cloud-init-no-dmidecode-on-ppc64.patch
Patch10:        cloud-init-no-user-lock-if-already-locked.patch
Patch11:        dataSourceOpenNebula.patch
Patch12:        fix-default-systemd-unit-dir.patch
Patch13:        no_logic_change.patch
Patch14:        cloud-init-finalbeforelogin.patch
# python2 disables SIGPIPE, causing broken pipe errors in shell scripts (bsc#903449)
Patch20:        cloud-init-python2-sigpipe.patch
BuildRequires:  fdupes
BuildRequires:  filesystem
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# pkg-config is needed to find correct systemd unit dir
BuildRequires:  pkg-config
Requires:       bash
Requires:       file
Requires:       growpart
Requires:       e2fsprogs
Requires:       openssh
Requires:       python-argparse
Requires:       python-boto >= 2.7
Requires:       python-cheetah
Requires:       python-configobj
Requires:       python-Jinja2
Requires:       python-jsonpatch
Requires:       python-oauth
Requires:       python-PrettyTable
Requires:       python-pyserial
Requires:       python-PyYAML
Requires:       python-requests
Requires:       python-xml
Requires:       sudo
Requires:       util-linux
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         docdir %{_defaultdocdir}/%{name}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%ifarch %ix86 x86_64
Requires:       pmtools
%endif
%else
%ifarch %ix86 x86_64
Requires:       dmidecode
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%define initsys sysvinit_suse
%else
%define initsys systemd
BuildRequires: systemd
Requires:      systemd
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} >= 1315
Requires:      wicked-service
%else
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
Requires:      sysconfig
%else
Requires:      sysconfig-network
%endif
%endif

%description
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

%package doc
Summary:        Cloud node initialization tool - Documentation
Group:          System/Management
Recommends:     cloud-init = %{version}

%description doc
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

Documentation and examples for cloud-init tools

%package test
Summary:        Cloud node initialization tool  - Testsuite
Group:          System/Management
Requires:       cloud-init = %{version}

%description test
Cloud-init is an init script that initializes a cloud node (VM)
according to the fetched configuration data from the admin node.

Unit tests for the cloud-init tools

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch3 -p1
%patch5
%patch6
%patch9 -p1
%patch10 -p1
%patch11 -p2
%patch12
%patch13
%patch14
%patch20 -p1

%if 0%{?suse_version} <= 1130
# disable ecdsa for SLE 11 (not available)
echo "ssh_genkeytypes: ['rsa', 'dsa']" >> %{SOURCE1}
%endif

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix} --install-lib=%{python_sitelib} --init-system=%{initsys}
find %{buildroot} \( -name .gitignore -o -name .placeholder \) -delete
# from debian install script
for x in "%{buildroot}%{_bindir}/"*.py; do
   [ -f "${x}" ] && mv "${x}" "${x%.py}"
done
mkdir -p %{buildroot}%{_localstatedir}/lib/cloud
# move documentation
mkdir -p %{buildroot}%{_defaultdocdir}
mv %{buildroot}%{_datadir}/doc/%{name} %{buildroot}%{docdir}
cp -a %{SOURCE1} %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
# copy the LICENSE
cp LICENSE %{buildroot}%{docdir}
# Set the distribution indicator
%if 0%{?suse_version}
%if 0%{?suse_version} < 1130
#SLE 11, openSUSE 11.x is EOL
sed -i s/INSERT_SUSE_DISTRO/sles/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%endif
%if 0%{?suse_version} > 1140
%if 0%{?suse_version} == 1315
# SLE 12
sed -i s/INSERT_SUSE_DISTRO/sles/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%else
sed -i s/INSERT_SUSE_DISTRO/opensuse/ %{buildroot}/%{_sysconfdir}/cloud/cloud.cfg
%endif
%endif
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
mkdir %{buildroot}/%{_sysconfdir}/rsyslog.d
cp -a %{SOURCE2} %{buildroot}/%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
%endif

# remove debian/ubuntu specific profile.d file (bnc#779553)
rm -f %{buildroot}%{_sysconfdir}/profile.d/Z99-cloud-locale-test.sh

# Remove non-SUSE templates
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.debian.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.redhat.*
rm %{buildroot}/%{_sysconfdir}/cloud/templates/*.ubuntu.*

# move sysvinit scripts into the "right" place
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
mkdir -p %{buildroot}/%{_initddir}
mkdir -p %{buildroot}/%{_sbindir}
pushd "%{buildroot}%{_initddir}"
for iniF in *; do
    ln -s "%{_initddir}/${iniF}" "%{buildroot}/%{_sbindir}/rc${iniF}"
done
popd
%endif

# remove duplicate files
%if 0%{?suse_version}
%fdupes %{buildroot}%{python_sitelib}
%endif

%postun
%insserv_cleanup

%files
%defattr(-,root,root)
# do not mark as doc or we get conflicts with the doc package
%{docdir}/LICENSE
%{_bindir}/cloud-init
%{_bindir}/cloud-init-per
%config(noreplace) %{_sysconfdir}/cloud/
%{python_sitelib}/cloudinit
%{python_sitelib}/cloud_init-%{version}-py%{py_ver}.egg-info
%{_prefix}/lib/cloud-init
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
%{_sbindir}/rccloud-config
%{_sbindir}/rccloud-init
%{_sbindir}/rccloud-init-local
%{_sbindir}/rccloud-final
%attr(0755, root, root) %{_initddir}/cloud-config
%attr(0755, root, root) %{_initddir}/cloud-init
%attr(0755, root, root) %{_initddir}/cloud-init-local
%attr(0755, root, root) %{_initddir}/cloud-final
%else
%{systemd_prefix}/systemd/system/cloud-config.service
%{systemd_prefix}/systemd/system/cloud-config.target
%{systemd_prefix}/systemd/system/cloud-init-local.service
%{systemd_prefix}/systemd/system/cloud-init.service
%{systemd_prefix}/systemd/system/cloud-final.service
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
%dir %{_sysconfdir}/rsyslog.d
%{_sysconfdir}/rsyslog.d/21-cloudinit.conf
%endif
%dir %attr(0755, root, root) %{_localstatedir}/lib/cloud
%dir %{docdir}


%files doc
%defattr(-,root,root)
%{docdir}/examples/*
%{docdir}/README
%{docdir}/*.txt
%{docdir}/*.rst
%dir %{docdir}/examples

%files test
%defattr(-,root,root)
%{python_sitelib}/tests

%changelog
* Mon Jun  6 2016 joachim.gleissner@suse.com
- Add cloud-init-python2-sigpipe.patch (bsc#903449)
  + Restore SIGPIPE default handler when executing shell scripts
* Tue May  3 2016 rjschwei@suse.com
- Add cloud-init-finalbeforelogin.patch (bsc#978048)
  + Ordering issue, avoid login prompt before cloud-init is finished
* Tue Mar 15 2016 rjschwei@suse.com
- Update suseIntegratedHandler.patch (bsc#971275)
  + Properly handle the package_upgrade configuration option
* Tue Oct  6 2015 rjschwei@suse.com
- Add dependency on jinja2 (bsc#948995,bsc#948996)
* Mon Jun 29 2015 rjschwei@suse.com
- Add no_logic_change.patch to undo upstream logic changes introduced during
  style clean up
* Wed May 20 2015 rjschwei@suse.com
- Properly write the routes file for static networks (bnc#920190)
  + modify suseIntegratedHandler.patch
- Remove suseSetInitCmd.patch
  + is now integrated with suseIntegratedHandler.patch
* Mon Apr 27 2015 rjschwei@suse.com
- pmtools only exist on Intel architecture (bnc#928552)
* Mon Apr 13 2015 tbechtold@suse.com
- update to 0.7.6:
  - open 0.7.6
  - Enable vendordata on CloudSigma datasource (LP: #1303986)
  - Poll on /dev/ttyS1 in CloudSigma datasource only if dmidecode says
    we're running on cloudsigma (LP: #1316475) [Kiril Vladimiroff]
  - SmartOS test: do not require existance of /dev/ttyS1. [LP: #1316597]
  - doc: fix user-groups doc to reference plural ssh-authorized-keys
    (LP: #1327065) [Joern Heissler]
  - fix 'make test' in python 2.6
  - support jinja2 as a templating engine.  Drop the hard requirement on
    cheetah.  This helps in python3 effort. (LP: #1219223)
  - change install path for systemd files to /lib/systemd/system
    [Dimitri John Ledkov]
  - change trunk debian packaging to use pybuild and drop cdbs.
    [Dimitri John Ledkov]
  - SeLinuxGuard: remove invalid check that looked for stat.st_mode in os.lstat.
  - do not write comments in /etc/timezone (LP: #1341710)
  - ubuntu: provide 'ubuntu-init-switch' module to aid in systemd testing.
  - status/result json: remove 'end' entry which was always null
  - systemd: make cloud-init block ssh service startup to guarantee keys
    are generated. [Jordan Evans] (LP: #1333920)
  - default settings: fix typo resulting in OpenStack and GCE not working
    unless config explicitly provided (LP: #1329583) [Garrett Holmstrom])
  - fix rendering resolv.conf if no 'options' are provided (LP: #1328953)
  - docs: fix disk-setup to reference 'table_type' [Rail Aliiev] (LP: #1313114)
  - ssh_authkey_fingerprints: fix bug that prevented disabling the module.
    (LP: #1340903) [Patrick Lucas]
  - no longer use pylint as a checker, fix pep8 [Jay Faulkner].
  - Openstack: do not load some urls twice.
  - FreeBsd: fix initscripts and add working config file [Harm Weites]
  - Datasource: fix broken logic to provide hostname if datasource does not
    provide one
  - Improved and less verbose logging.
  - resizefs: first check that device is writable.
  - configdrive: fix reading of vendor data to be like metadata service reader.
    [Jay Faulkner]
  - resizefs: fix broken background resizing [Jay Faulkner] (LP: #1338614)
  - cc_grub_dpkg: fix EC2 hvm instances to avoid prompt on grub update.
    (LP: #1336855)
  - FreeBsd: support config drive datasource [Joseph bajin]
  - cc_mounts: support creating a swap file
- Refresh addopenSUSEBase.patch
- Refresh setupSUSEsysVInit.diff
- Removed cloudinit-datasources.patch. Applied upstream
- BuildRequires pkg-config. Needed to find correct systemd unit dir.
- Add fix-default-systemd-unit-dir.patch . Use better default for
  systemd system unit dir.
* Tue Feb 24 2015 rjschwei@suse.com
- Fix (bnc#919305 & bnc#918952)
  - Properly handle persistent network device names for OpenNebula
    + add dataSourceOpenNebula.patch
  - Properly set up network mode if interface config file
    + modified suseIntegratedHandler.patch
* Thu Feb  5 2015 tbechtold@suse.com
- Require e2fsprogs for filesystem resizing
* Tue Feb  3 2015 tbechtold@suse.com
- Remove Requires for python-yaml . There's already the right
  requirement for python-PyYAML
* Fri Nov 21 2014 reik.keutterling@nodefall.de
- fixed syntax error in dmidecode on ppc64 patch (bnc#914920)
* Tue Sep 16 2014 ms@suse.de
- users-groups module checks if the account is locked by
  calling 'passwd -l' which is ok but it should not raise
  if the account is already locked. This patch will cause
  lock_passwd to raise only if the account locking failed
  cloud-init-no-user-lock-if-already-locked.patch
* Sat Aug  9 2014 dvlaeev@suse.com
- Make package Arch dependent otherwise package is not installable
  on architectures where dmidecode is not available.
- Avoid to run dmidecode on PowerPC as well
  cloud-init-no-dmidecode-on-ppc64.patch
* Mon Jul 28 2014 rschweikert@suse.com
- declare rsyslog.d only for distros where it is created
  fixes build error on SLE 11
* Mon Jul 28 2014 rschweikert@suse.com
- add dmidecode (pmtools SLE 11) as dependency (bnc #888345)
* Tue Jul 22 2014 dmueller@suse.com
- fix typo in cloud.cfg (gowpart -> growpart)
- add cloudinit-datasources.patch: Fixes datasource list
* Mon Jul  7 2014 rschweikert@suse.com
- fix "typo" the rhel_util module is imported as rhutil, use the
  proper name when accessing (modifies suseIntegratedHandler.patch)
* Thu Jun 26 2014 rschweikert@suse.com
- add rsyslog filter rule to send cloud-init messages to
  /var/log/cloud-init.log
* Wed Jun 25 2014 rschweikert@suse.com
- initialize variable in method setting the instance hostname (BNC #884392)
  modifies: suseIntegratedHandler.patch
* Tue Jun 24 2014 rschweikert@suse.com
- add the python magic for package build on SLE 11
* Tue Jun 24 2014 rschweikert@suse.com
- add more dependencies to ensure commands used by the scripts are present
- add dynamicInitCmd.diff
  + support diffirent init systems across distribution versions for
    service restart
- add suseSetInitCmd.patch
  + properly setup the init command to support proper service restart
* Fri Jun 20 2014 rschweikert@suse.com
- integrate openSUSE and SLE handler code
  + remove openSUSEHandler.diff
  + add suseIntegratedHandler.patch
* Mon Apr 14 2014 rschweikert@suse.com
- update to version 0.7.5
  - open 0.7.5
  - Add a debug log message around import failures
  - add a 'debug' module for easily printing out some information about
    datasource and cloud-init [Shraddha Pandhe]
  - support running apt with 'eatmydata' via configuration token
    apt_get_wrapper (LP: #1236531).
  - convert paths provided in config-drive 'files' to string before writing
    (LP: #1260072).
  - Azure: minor changes in logging output. ensure filenames are strings (not
    unicode).
  - config/cloud.cfg.d/05_logging.cfg: provide a default 'output' setting, to
    redirect cloud-init stderr and stdout /var/log/cloud-init-output.log.
  - drop support for resizing partitions with parted entirely (LP: #1212492).
    This was broken as it was anyway.
  - add support for vendordata in SmartOS and NoCloud datasources.
  - drop dependency on boto for crawling ec2 metadata service.
  - add 'Requires' on sudo (for OpenNebula datasource) in rpm specs, and
    'Recommends' in the debian/control.in [Vlastimil Holer]
  - if mount_info reports /dev/root is a device path for /, then convert
    that to a device via help of kernel cmdline.
  - configdrive: consider partitions as possible datasources if they have
    theh correct filesystem label. [Paul Querna]
  - initial freebsd support [Harm Weites]
  - fix in is_ipv4 to accept IP addresses with a '0' in them.
  - Azure: fix issue when stale data in /var/lib/waagent (LP: #1269626)
  - skip config_modules that declare themselves only verified on a set of
    distros.  Add them to 'unverified_modules' list to run anyway.
  - Add CloudSigma datasource [Kiril Vladimiroff]
  - Add initial support for Gentoo and Arch distributions [Nate House]
  - Add GCE datasource [Vaidas Jablonskis]
  - Add native Openstack datasource which reads openstack metadata
    rather than relying on EC2 data in openstack metadata service.
  - SmartOS, AltCloud: disable running on arm systems due to bug
    (LP: #1243287, #1285686) [Oleg Strikov]
  - Allow running a command to seed random, default is 'pollinate -q'
    (LP: #1286316) [Dustin Kirkland]
  - Write status to /run/cloud-init/status.json for consumption by
    other programs (LP: #1284439)
  - Azure: if a reboot causes ephemeral storage to be re-provisioned
    Then we need to re-format it. (LP: #1292648)
  - OpenNebula: support base64 encoded user-data
    [Enol Fernandez, Peter Kotcauer]
- remove azure_1269626.diff, fix integrated in new version
- rename addopenSUSEBase.diff to addopenSUSEBase.patch, forward port
* Sat Mar 29 2014 rschweikert@suse.com
- fix implementation of the openSUSE handler, properly read the configuration
  from sysconfig
* Wed Mar 19 2014 rschweikert@suse.com
- do not package any none SUSE/openSUSE templates bnc#839707
- add patch openSUSEhostsTemplate.diff to add an openSUSE hosts template
* Wed Mar 19 2014 rschweikert@suse.com
- enable growing of root partition by default bnc#861473
* Tue Mar 18 2014 rschweikert@suse.com
- include the LICENSE
* Mon Mar 17 2014 rschweikert@suse.com
- include in SLE 12 (FATE #315990, #315991, and 316167)
- add patch azure_1269626.diff, fix for upstream bug 1269626
  + Azure instance do not boot properly after a capture operation
* Mon Mar 17 2014 rschweikert@suse.com
- add dependency on growpart to support root partition expansion
* Mon Jan 20 2014 dmueller@suse.com
- add python-jsonpatch, python-pyserial, python-PyYAML requires,
  otherwise it immediately traces on startup
* Sat Jan  4 2014 rschweikert@suse.com
- update to version 0.7.4
  + fix issue mounting 'ephemeral0' if ephemeral0 was an alias for a
    partitioned block device with target filesystem on ephemeral0.1.
    (LP: #1236594)
  + fix DataSourceAzure incompatibility with 2.6 (LP: #1232175)
  + fix power_state_change config module so that example works.  Improve
    its documentation and add reference to 'timeout'
  + support apt-add-archive with 'cloud-archive:' format.  (LP: #1244355)
  + Change SmartOS verb for availability zone (LP: #1249124)
  + documentation fix for boothooks to use 'cloud-init-per'
  + fix resizefs module by supporting kernels that do not have
    /proc/PID/mountinfo.  (LP: #1248625) [Tim Daly Jr.]
  + fix 'make rpm' by removing 0.6.4 entry from ChangeLog (LP: #1241834)
  + fix omnibus chef installer (LP: #1182265) [Chris Wing]
  + small fix for OVF datasource for iso transport on non-iso9660 filesystem
  + determine if upstart version is suitable for
    'initctl reload-configuration' (LP: #1124384).  If so, then invoke it.
    supports setting up instance-store disk with partition table and filesystem.
  + add Azure datasource.
  + add support for SuSE / SLES [Juerg Haefliger]
  + add a trailing carriage return to chpasswd input, which reportedly
    caused a problem on rhel5 if missing.
  + support individual MIME segments to be gzip compressed (LP: #1203203)
  + always finalize handlers even if processing failed (LP: #1203368)
  + support merging into cloud-config via jsonp. (LP: #1200476)
  + add datasource 'SmartOS' for Joyent Cloud.  Adds a dependency on serial.
  + add 'log_time' helper to util for timing how long things take
    which also reads from uptime. uptime is useful as clock may change during
    boot due to ntp.
  + prefer growpart resizer to 'parted resizepart' (LP: #1212492)
  + support random data seed from config drive or azure, and a module
    'seed_random' to read that and write it to /dev/urandom.
  + add OpenNebula Datasource [Vlastimil Holer]
  + add 'cc_disk_setup' config module for paritioning disks and creating
    filesystems.  Useful if attached disks are not formatted (LP: #1218506)
  + Fix usage of libselinux-python when selinux is disabled. [Garrett Holmstrom]
  + multi_log: only write to /dev/console if it exists [Garrett Holmstrom]
  + config/cloud.cfg: add 'sudo' to list groups for the default user
    (LP: #1228228)
  + documentation fix for use of 'mkpasswd' [Eric Nordlund]
  + respect /etc/growroot-disabled file (LP: #1234331)
- replace fixupSysVinit.patch with suseSysVInit.diff
  + sysV init files are now maintained by distribution, thus we need a patch
    that has the complete sysV init files rather then modifying existing files
- remove slesHandler.patch
  + SLES support is now integrated upstream
- add addopenSUSEBase.diff
  + remnants of the slesHandler.patch that add information about openSUSE
- add setupSUSEsysVInit.diff
  + integrate the SUSE sysV init scripts into setup.py
* Fri Aug  2 2013 rschweikert@suse.com
- remove the "nofail" option for the ephemeral storage
  + when using nofail an attempt is made to mount the filesystem twice
    once via udev and once through localfs, this results in a hanging
    system if fsck needs to run on the device
* Thu Jul 11 2013 speilicke@suse.com
- Install service files into /lib/systemd/system on 12.2, the UsrMove
  happened afterwards
* Wed Jul 10 2013 speilicke@suse.com
- Re-imported from IBS and some cleanup
- Package LICENSE
- Install service files to /usr/lib/systemd/system, not /etc/...
- Drop %%py_requires, there are several autorequires for SLES and openSUSE
- Drop $all facility Required-Start in sysvinit/cloud-final
* Wed Jun 26 2013 bwiedemann@suse.com
- require python-boto >= 2.7 because it fails with 2.5.2
* Wed Jun 26 2013 rschweikert@suse.com
- fix stray character in patch introduced by previous changes
* Wed Jun 26 2013 rschweikert@suse.com
- fix zypper command in slesHandler, use non-interactive mode
* Wed Jun 19 2013 rschweikert@suse.com
- fix duplicate entry in the config w.r.t. ssh key generation
- fix distro indicator setting, sles vs. opensuse
* Tue Jun 18 2013 rschweikert@suse.com
- Integrate the sysV init script changes from Jens
* Tue Jun 18 2013 rschweikert@suse.com
- integrate changes from HP
  + update the sles handler, do not modify the util code integrate
    routines directky into the sles handler
    ~ add patch slesHandler.patch
    ~ remove patch openSUSEHandler.diff
  + add python dependencies
    ~ python-argparse
    ~ python-configobj
    ~ python-oauth
  + update the cloud-init config file
* Sat Jun 15 2013 rschweikert@suse.com
- add the distro specific handler for openSUSE
  + patch openSUSEHandler.diff
- fix syntax in SLE handler
  + dict access uses [] not {}, duh
* Fri Jun 14 2013 rschweikert@suse.com
- add the distro specific handler for SLE
  + patch slesHandler.diff
* Wed Jun  5 2013 rschweikert@suse.com
- update to version 0.7.2, see Changelog in source for fixes
- use the upstream sysvinit and systemd files
- remove all previously created patches
  + drop-MAAS-datasource.diff
  + drop-python27-only-code.diff
  + drop-ubuntu-default-username.diff
  + relative-authorized-keys-file.diff
- create a doc and test package to reduce size of main package
- add patch (fixupSysVinit.patch) to fix the upstream sysvinit LSB headers
* Mon May  6 2013 jdsn@suse.de
- support relative path for authorized_keys file
  backport fix from upstream version 0.7.1 (bnc#818306)
* Wed Sep 19 2012 jdsn@suse.de
- fix usage of patches for openSUSE builds
* Thu Sep 13 2012 jdsn@suse.de
- drop ubuntu as default user name
- disable ssh ecdsa host key creation on SLE11
* Wed Sep 12 2012 jdsn@suse.de
- replace python 2.7 code with 2.5 compliant code
* Tue Sep 11 2012 jdsn@suse.de
- drop debian specific checks (bnc#779553)
* Mon Sep 10 2012 jdsn@suse.com
- Add python-xml Requires that was missing (bnc#779588).
* Fri Jul 20 2012 jdsn@suse.com
- fix init script, use killproc for stop operation (bnc#771803)
* Tue Jul  3 2012 cthiel@suse.com
- change license to SPDX format
* Wed Jun 27 2012 jdsn@suse.de
- rename to cloud-init
- drop MAAS support to avoid oauth dependency
